# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/cacheservice/cacheservice.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import types_pb2 as flyteidl_dot_core_dot_types__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import interface_pb2 as flyteidl_dot_core_dot_interface__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(flyteidl/cacheservice/cacheservice.proto\x12\x15\x66lyteidl.cacheservice\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x19\x66lyteidl/core/types.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1d\x66lyteidl/core/interface.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x96\x01\n\x0eKeyMapMetadata\x12I\n\x06values\x18\x01 \x03(\x0b\x32\x31.flyteidl.cacheservice.KeyMapMetadata.ValuesEntryR\x06values\x1a\x39\n\x0bValuesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\x91\x02\n\x08Metadata\x12\x46\n\x11source_identifier\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x10sourceIdentifier\x12>\n\x07key_map\x18\x02 \x01(\x0b\x32%.flyteidl.cacheservice.KeyMapMetadataR\x06keyMap\x12\x39\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12\x42\n\x0flast_updated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rlastUpdatedAt\"\xbc\x01\n\x0c\x43\x61\x63hedOutput\x12\x44\n\x0foutput_literals\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapH\x00R\x0eoutputLiterals\x12\x1f\n\noutput_uri\x18\x02 \x01(\tH\x00R\toutputUri\x12;\n\x08metadata\x18\x03 \x01(\x0b\x32\x1f.flyteidl.cacheservice.MetadataR\x08metadataB\x08\n\x06output\"#\n\x0fGetCacheRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\"O\n\x10GetCacheResponse\x12;\n\x06output\x18\x01 \x01(\x0b\x32#.flyteidl.cacheservice.CachedOutputR\x06output\"~\n\x0fPutCacheRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12;\n\x06output\x18\x02 \x01(\x0b\x32#.flyteidl.cacheservice.CachedOutputR\x06output\x12\x1c\n\toverwrite\x18\x03 \x01(\x08R\toverwrite\"\x12\n\x10PutCacheResponse\"&\n\x12\x44\x65leteCacheRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\"\x15\n\x13\x44\x65leteCacheResponse\"\xbf\x01\n\x0bReservation\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x19\n\x08owner_id\x18\x02 \x01(\tR\x07ownerId\x12H\n\x12heartbeat_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11heartbeatInterval\x12\x39\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\"\x96\x01\n\x1dGetOrExtendReservationRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x19\n\x08owner_id\x18\x02 \x01(\tR\x07ownerId\x12H\n\x12heartbeat_interval\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11heartbeatInterval\"f\n\x1eGetOrExtendReservationResponse\x12\x44\n\x0breservation\x18\x01 \x01(\x0b\x32\".flyteidl.cacheservice.ReservationR\x0breservation\"H\n\x19ReleaseReservationRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x19\n\x08owner_id\x18\x02 \x01(\tR\x07ownerId\"\x1c\n\x1aReleaseReservationResponse2\xa2\x04\n\x0c\x43\x61\x63heService\x12V\n\x03Get\x12&.flyteidl.cacheservice.GetCacheRequest\x1a\'.flyteidl.cacheservice.GetCacheResponse\x12V\n\x03Put\x12&.flyteidl.cacheservice.PutCacheRequest\x1a\'.flyteidl.cacheservice.PutCacheResponse\x12_\n\x06\x44\x65lete\x12).flyteidl.cacheservice.DeleteCacheRequest\x1a*.flyteidl.cacheservice.DeleteCacheResponse\x12\x85\x01\n\x16GetOrExtendReservation\x12\x34.flyteidl.cacheservice.GetOrExtendReservationRequest\x1a\x35.flyteidl.cacheservice.GetOrExtendReservationResponse\x12y\n\x12ReleaseReservation\x12\x30.flyteidl.cacheservice.ReleaseReservationRequest\x1a\x31.flyteidl.cacheservice.ReleaseReservationResponseB\xe7\x01\n\x19\x63om.flyteidl.cacheserviceB\x11\x43\x61\x63heserviceProtoP\x01ZBgithub.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/cacheservice\xa2\x02\x03\x46\x43X\xaa\x02\x15\x46lyteidl.Cacheservice\xca\x02\x15\x46lyteidl\\Cacheservice\xe2\x02!Flyteidl\\Cacheservice\\GPBMetadata\xea\x02\x16\x46lyteidl::Cacheserviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.cacheservice.cacheservice_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.flyteidl.cacheserviceB\021CacheserviceProtoP\001ZBgithub.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/cacheservice\242\002\003FCX\252\002\025Flyteidl.Cacheservice\312\002\025Flyteidl\\Cacheservice\342\002!Flyteidl\\Cacheservice\\GPBMetadata\352\002\026Flyteidl::Cacheservice'
  _KEYMAPMETADATA_VALUESENTRY._options = None
  _KEYMAPMETADATA_VALUESENTRY._serialized_options = b'8\001'
  _globals['_KEYMAPMETADATA']._serialized_start=253
  _globals['_KEYMAPMETADATA']._serialized_end=403
  _globals['_KEYMAPMETADATA_VALUESENTRY']._serialized_start=346
  _globals['_KEYMAPMETADATA_VALUESENTRY']._serialized_end=403
  _globals['_METADATA']._serialized_start=406
  _globals['_METADATA']._serialized_end=679
  _globals['_CACHEDOUTPUT']._serialized_start=682
  _globals['_CACHEDOUTPUT']._serialized_end=870
  _globals['_GETCACHEREQUEST']._serialized_start=872
  _globals['_GETCACHEREQUEST']._serialized_end=907
  _globals['_GETCACHERESPONSE']._serialized_start=909
  _globals['_GETCACHERESPONSE']._serialized_end=988
  _globals['_PUTCACHEREQUEST']._serialized_start=990
  _globals['_PUTCACHEREQUEST']._serialized_end=1116
  _globals['_PUTCACHERESPONSE']._serialized_start=1118
  _globals['_PUTCACHERESPONSE']._serialized_end=1136
  _globals['_DELETECACHEREQUEST']._serialized_start=1138
  _globals['_DELETECACHEREQUEST']._serialized_end=1176
  _globals['_DELETECACHERESPONSE']._serialized_start=1178
  _globals['_DELETECACHERESPONSE']._serialized_end=1199
  _globals['_RESERVATION']._serialized_start=1202
  _globals['_RESERVATION']._serialized_end=1393
  _globals['_GETOREXTENDRESERVATIONREQUEST']._serialized_start=1396
  _globals['_GETOREXTENDRESERVATIONREQUEST']._serialized_end=1546
  _globals['_GETOREXTENDRESERVATIONRESPONSE']._serialized_start=1548
  _globals['_GETOREXTENDRESERVATIONRESPONSE']._serialized_end=1650
  _globals['_RELEASERESERVATIONREQUEST']._serialized_start=1652
  _globals['_RELEASERESERVATIONREQUEST']._serialized_end=1724
  _globals['_RELEASERESERVATIONRESPONSE']._serialized_start=1726
  _globals['_RELEASERESERVATIONRESPONSE']._serialized_end=1754
  _globals['_CACHESERVICE']._serialized_start=1757
  _globals['_CACHESERVICE']._serialized_end=2303
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/description_entity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'flyteidl/admin/description_entity.proto\x12\x0e\x66lyteidl.admin\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1b\x66lyteidl/admin/common.proto\"\x84\x02\n\x11\x44\x65scriptionEntity\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.IdentifierR\x02id\x12+\n\x11short_description\x18\x02 \x01(\tR\x10shortDescription\x12\x46\n\x10long_description\x18\x03 \x01(\x0b\x32\x1b.flyteidl.admin.DescriptionR\x0flongDescription\x12;\n\x0bsource_code\x18\x04 \x01(\x0b\x32\x1a.flyteidl.admin.SourceCodeR\nsourceCode\x12\x12\n\x04tags\x18\x05 \x03(\tR\x04tags\"\x9c\x01\n\x0b\x44\x65scription\x12\x16\n\x05value\x18\x01 \x01(\tH\x00R\x05value\x12\x12\n\x03uri\x18\x02 \x01(\tH\x00R\x03uri\x12\x39\n\x06\x66ormat\x18\x03 \x01(\x0e\x32!.flyteidl.admin.DescriptionFormatR\x06\x66ormat\x12\x1b\n\ticon_link\x18\x04 \x01(\tR\x08iconLinkB\t\n\x07\x63ontent\" \n\nSourceCode\x12\x12\n\x04link\x18\x01 \x01(\tR\x04link\"\x82\x01\n\x15\x44\x65scriptionEntityList\x12S\n\x13\x64\x65scriptionEntities\x18\x01 \x03(\x0b\x32!.flyteidl.admin.DescriptionEntityR\x13\x64\x65scriptionEntities\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\"\x8c\x02\n\x1c\x44\x65scriptionEntityListRequest\x12@\n\rresource_type\x18\x01 \x01(\x0e\x32\x1b.flyteidl.core.ResourceTypeR\x0cresourceType\x12\x35\n\x02id\x18\x02 \x01(\x0b\x32%.flyteidl.admin.NamedEntityIdentifierR\x02id\x12\x14\n\x05limit\x18\x03 \x01(\rR\x05limit\x12\x14\n\x05token\x18\x04 \x01(\tR\x05token\x12\x18\n\x07\x66ilters\x18\x05 \x01(\tR\x07\x66ilters\x12-\n\x07sort_by\x18\x06 \x01(\x0b\x32\x14.flyteidl.admin.SortR\x06sortBy*\x8d\x01\n\x11\x44\x65scriptionFormat\x12\x1e\n\x1a\x44\x45SCRIPTION_FORMAT_UNKNOWN\x10\x00\x12\x1f\n\x1b\x44\x45SCRIPTION_FORMAT_MARKDOWN\x10\x01\x12\x1b\n\x17\x44\x45SCRIPTION_FORMAT_HTML\x10\x02\x12\x1a\n\x16\x44\x45SCRIPTION_FORMAT_RST\x10\x03\x42\xc2\x01\n\x12\x63om.flyteidl.adminB\x16\x44\x65scriptionEntityProtoP\x01Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\xa2\x02\x03\x46\x41X\xaa\x02\x0e\x46lyteidl.Admin\xca\x02\x0e\x46lyteidl\\Admin\xe2\x02\x1a\x46lyteidl\\Admin\\GPBMetadata\xea\x02\x0f\x46lyteidl::Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.admin.description_entity_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022com.flyteidl.adminB\026DescriptionEntityProtoP\001Z;github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/admin\242\002\003FAX\252\002\016Flyteidl.Admin\312\002\016Flyteidl\\Admin\342\002\032Flyteidl\\Admin\\GPBMetadata\352\002\017Flyteidl::Admin'
  _globals['_DESCRIPTIONFORMAT']._serialized_start=981
  _globals['_DESCRIPTIONFORMAT']._serialized_end=1122
  _globals['_DESCRIPTIONENTITY']._serialized_start=121
  _globals['_DESCRIPTIONENTITY']._serialized_end=381
  _globals['_DESCRIPTION']._serialized_start=384
  _globals['_DESCRIPTION']._serialized_end=540
  _globals['_SOURCECODE']._serialized_start=542
  _globals['_SOURCECODE']._serialized_end=574
  _globals['_DESCRIPTIONENTITYLIST']._serialized_start=577
  _globals['_DESCRIPTIONENTITYLIST']._serialized_end=707
  _globals['_DESCRIPTIONENTITYLISTREQUEST']._serialized_start=710
  _globals['_DESCRIPTIONENTITYLISTREQUEST']._serialized_end=978
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DistributedMPITrainingTask(_message.Message):
    __slots__ = ["num_workers", "num_launcher_replicas", "slots"]
    NUM_WORKERS_FIELD_NUMBER: _ClassVar[int]
    NUM_LAUNCHER_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    SLOTS_FIELD_NUMBER: _ClassVar[int]
    num_workers: int
    num_launcher_replicas: int
    slots: int
    def __init__(self, num_workers: _Optional[int] = ..., num_launcher_replicas: _Optional[int] = ..., slots: _Optional[int] = ...) -> None: ...



from flyteidl.core import identifier_pb2 as _identifier_pb2
from flyteidl.core import interface_pb2 as _interface_pb2
from flyteidl.core import workflow_pb2 as _workflow_pb2
from flyteidl.core import tasks_pb2 as _tasks_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ConnectionSet(_message.Message):
    __slots__ = ["downstream", "upstream"]
    class IdList(_message.Message):
        __slots__ = ["ids"]
        IDS_FIELD_NUMBER: _ClassVar[int]
        ids: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, ids: _Optional[_Iterable[str]] = ...) -> None: ...
    class DownstreamEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ConnectionSet.IdList
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ConnectionSet.IdList, _Mapping]] = ...) -> None: ...
    class UpstreamEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: ConnectionSet.IdList
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[ConnectionSet.IdList, _Mapping]] = ...) -> None: ...
    DOWNSTREAM_FIELD_NUMBER: _ClassVar[int]
    UPSTREAM_FIELD_NUMBER: _ClassVar[int]
    downstream: _containers.MessageMap[str, ConnectionSet.IdList]
    upstream: _containers.MessageMap[str, ConnectionSet.IdList]
    def __init__(self, downstream: _Optional[_Mapping[str, ConnectionSet.IdList]] = ..., upstream: _Optional[_Mapping[str, ConnectionSet.IdList]] = ...) -> None: ...

class CompiledWorkflow(_message.Message):
    __slots__ = ["template", "connections"]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    CONNECTIONS_FIELD_NUMBER: _ClassVar[int]
    template: _workflow_pb2.WorkflowTemplate
    connections: ConnectionSet
    def __init__(self, template: _Optional[_Union[_workflow_pb2.WorkflowTemplate, _Mapping]] = ..., connections: _Optional[_Union[ConnectionSet, _Mapping]] = ...) -> None: ...

class CompiledLaunchPlan(_message.Message):
    __slots__ = ["template"]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template: _workflow_pb2.LaunchPlanTemplate
    def __init__(self, template: _Optional[_Union[_workflow_pb2.LaunchPlanTemplate, _Mapping]] = ...) -> None: ...

class CompiledTask(_message.Message):
    __slots__ = ["template"]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    template: _tasks_pb2.TaskTemplate
    def __init__(self, template: _Optional[_Union[_tasks_pb2.TaskTemplate, _Mapping]] = ...) -> None: ...

class CompiledWorkflowClosure(_message.Message):
    __slots__ = ["primary", "sub_workflows", "tasks", "launch_plans"]
    PRIMARY_FIELD_NUMBER: _ClassVar[int]
    SUB_WORKFLOWS_FIELD_NUMBER: _ClassVar[int]
    TASKS_FIELD_NUMBER: _ClassVar[int]
    LAUNCH_PLANS_FIELD_NUMBER: _ClassVar[int]
    primary: CompiledWorkflow
    sub_workflows: _containers.RepeatedCompositeFieldContainer[CompiledWorkflow]
    tasks: _containers.RepeatedCompositeFieldContainer[CompiledTask]
    launch_plans: _containers.RepeatedCompositeFieldContainer[CompiledLaunchPlan]
    def __init__(self, primary: _Optional[_Union[CompiledWorkflow, _Mapping]] = ..., sub_workflows: _Optional[_Iterable[_Union[CompiledWorkflow, _Mapping]]] = ..., tasks: _Optional[_Iterable[_Union[CompiledTask, _Mapping]]] = ..., launch_plans: _Optional[_Iterable[_Union[CompiledLaunchPlan, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from flyteidl.service import external_plugin_service_pb2 as flyteidl_dot_service_dot_external__plugin__service__pb2


class ExternalPluginServiceStub(object):
    """ExternalPluginService defines an RPC Service that allows propeller to send the request to the backend plugin server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTask = channel.unary_unary(
                '/flyteidl.service.ExternalPluginService/CreateTask',
                request_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateResponse.FromString,
                )
        self.GetTask = channel.unary_unary(
                '/flyteidl.service.ExternalPluginService/GetTask',
                request_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetResponse.FromString,
                )
        self.DeleteTask = channel.unary_unary(
                '/flyteidl.service.ExternalPluginService/DeleteTask',
                request_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteRequest.SerializeToString,
                response_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteResponse.FromString,
                )


class ExternalPluginServiceServicer(object):
    """ExternalPluginService defines an RPC Service that allows propeller to send the request to the backend plugin server.
    """

    def CreateTask(self, request, context):
        """Send a task create request to the backend plugin server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTask(self, request, context):
        """Get job status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTask(self, request, context):
        """Delete the task resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExternalPluginServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTask': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTask,
                    request_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateRequest.FromString,
                    response_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateResponse.SerializeToString,
            ),
            'GetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTask,
                    request_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetRequest.FromString,
                    response_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetResponse.SerializeToString,
            ),
            'DeleteTask': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTask,
                    request_deserializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteRequest.FromString,
                    response_serializer=flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'flyteidl.service.ExternalPluginService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExternalPluginService(object):
    """ExternalPluginService defines an RPC Service that allows propeller to send the request to the backend plugin server.
    """

    @staticmethod
    def CreateTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.ExternalPluginService/CreateTask',
            flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateRequest.SerializeToString,
            flyteidl_dot_service_dot_external__plugin__service__pb2.TaskCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.ExternalPluginService/GetTask',
            flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetRequest.SerializeToString,
            flyteidl_dot_service_dot_external__plugin__service__pb2.TaskGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.ExternalPluginService/DeleteTask',
            flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteRequest.SerializeToString,
            flyteidl_dot_service_dot_external__plugin__service__pb2.TaskDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from flyteidl.core import tasks_pb2 as _tasks_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RayJob(_message.Message):
    __slots__ = ["ray_cluster", "runtime_env", "shutdown_after_job_finishes", "ttl_seconds_after_finished", "runtime_env_yaml"]
    RAY_CLUSTER_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ENV_FIELD_NUMBER: _ClassVar[int]
    SHUTDOWN_AFTER_JOB_FINISHES_FIELD_NUMBER: _ClassVar[int]
    TTL_SECONDS_AFTER_FINISHED_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ENV_YAML_FIELD_NUMBER: _ClassVar[int]
    ray_cluster: RayCluster
    runtime_env: str
    shutdown_after_job_finishes: bool
    ttl_seconds_after_finished: int
    runtime_env_yaml: str
    def __init__(self, ray_cluster: _Optional[_Union[RayCluster, _Mapping]] = ..., runtime_env: _Optional[str] = ..., shutdown_after_job_finishes: bool = ..., ttl_seconds_after_finished: _Optional[int] = ..., runtime_env_yaml: _Optional[str] = ...) -> None: ...

class RayCluster(_message.Message):
    __slots__ = ["head_group_spec", "worker_group_spec", "enable_autoscaling"]
    HEAD_GROUP_SPEC_FIELD_NUMBER: _ClassVar[int]
    WORKER_GROUP_SPEC_FIELD_NUMBER: _ClassVar[int]
    ENABLE_AUTOSCALING_FIELD_NUMBER: _ClassVar[int]
    head_group_spec: HeadGroupSpec
    worker_group_spec: _containers.RepeatedCompositeFieldContainer[WorkerGroupSpec]
    enable_autoscaling: bool
    def __init__(self, head_group_spec: _Optional[_Union[HeadGroupSpec, _Mapping]] = ..., worker_group_spec: _Optional[_Iterable[_Union[WorkerGroupSpec, _Mapping]]] = ..., enable_autoscaling: bool = ...) -> None: ...

class HeadGroupSpec(_message.Message):
    __slots__ = ["ray_start_params", "k8s_pod"]
    class RayStartParamsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    RAY_START_PARAMS_FIELD_NUMBER: _ClassVar[int]
    K8S_POD_FIELD_NUMBER: _ClassVar[int]
    ray_start_params: _containers.ScalarMap[str, str]
    k8s_pod: _tasks_pb2.K8sPod
    def __init__(self, ray_start_params: _Optional[_Mapping[str, str]] = ..., k8s_pod: _Optional[_Union[_tasks_pb2.K8sPod, _Mapping]] = ...) -> None: ...

class WorkerGroupSpec(_message.Message):
    __slots__ = ["group_name", "replicas", "min_replicas", "max_replicas", "ray_start_params", "k8s_pod"]
    class RayStartParamsEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    GROUP_NAME_FIELD_NUMBER: _ClassVar[int]
    REPLICAS_FIELD_NUMBER: _ClassVar[int]
    MIN_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    MAX_REPLICAS_FIELD_NUMBER: _ClassVar[int]
    RAY_START_PARAMS_FIELD_NUMBER: _ClassVar[int]
    K8S_POD_FIELD_NUMBER: _ClassVar[int]
    group_name: str
    replicas: int
    min_replicas: int
    max_replicas: int
    ray_start_params: _containers.ScalarMap[str, str]
    k8s_pod: _tasks_pb2.K8sPod
    def __init__(self, group_name: _Optional[str] = ..., replicas: _Optional[int] = ..., min_replicas: _Optional[int] = ..., max_replicas: _Optional[int] = ..., ray_start_params: _Optional[_Mapping[str, str]] = ..., k8s_pod: _Optional[_Union[_tasks_pb2.K8sPod, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/interface.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import types_pb2 as flyteidl_dot_core_dot_types__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import artifact_id_pb2 as flyteidl_dot_core_dot_artifact__id__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x66lyteidl/core/interface.proto\x12\rflyteidl.core\x1a\x19\x66lyteidl/core/types.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1f\x66lyteidl/core/artifact_id.proto\"\xe6\x01\n\x08Variable\x12.\n\x04type\x18\x01 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeR\x04type\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription\x12I\n\x13\x61rtifact_partial_id\x18\x03 \x01(\x0b\x32\x19.flyteidl.core.ArtifactIDR\x11\x61rtifactPartialId\x12=\n\x0c\x61rtifact_tag\x18\x04 \x01(\x0b\x32\x1a.flyteidl.core.ArtifactTagR\x0b\x61rtifactTag\"\xad\x01\n\x0bVariableMap\x12G\n\tvariables\x18\x01 \x03(\x0b\x32).flyteidl.core.VariableMap.VariablesEntryR\tvariables\x1aU\n\x0eVariablesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x17.flyteidl.core.VariableR\x05value:\x02\x38\x01\"z\n\x0eTypedInterface\x12\x32\n\x06inputs\x18\x01 \x01(\x0b\x32\x1a.flyteidl.core.VariableMapR\x06inputs\x12\x34\n\x07outputs\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.VariableMapR\x07outputs\"\x99\x02\n\tParameter\x12)\n\x03var\x18\x01 \x01(\x0b\x32\x17.flyteidl.core.VariableR\x03var\x12\x32\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x0b\x32\x16.flyteidl.core.LiteralH\x00R\x07\x64\x65\x66\x61ult\x12\x1c\n\x08required\x18\x03 \x01(\x08H\x00R\x08required\x12\x45\n\x0e\x61rtifact_query\x18\x04 \x01(\x0b\x32\x1c.flyteidl.core.ArtifactQueryH\x00R\rartifactQuery\x12<\n\x0b\x61rtifact_id\x18\x05 \x01(\x0b\x32\x19.flyteidl.core.ArtifactIDH\x00R\nartifactIdB\n\n\x08\x62\x65havior\"\xb4\x01\n\x0cParameterMap\x12K\n\nparameters\x18\x01 \x03(\x0b\x32+.flyteidl.core.ParameterMap.ParametersEntryR\nparameters\x1aW\n\x0fParametersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x18.flyteidl.core.ParameterR\x05value:\x02\x38\x01\x42\xb4\x01\n\x11\x63om.flyteidl.coreB\x0eInterfaceProtoP\x01Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\xa2\x02\x03\x46\x43X\xaa\x02\rFlyteidl.Core\xca\x02\rFlyteidl\\Core\xe2\x02\x19\x46lyteidl\\Core\\GPBMetadata\xea\x02\x0e\x46lyteidl::Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.core.interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.flyteidl.coreB\016InterfaceProtoP\001Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\242\002\003FCX\252\002\rFlyteidl.Core\312\002\rFlyteidl\\Core\342\002\031Flyteidl\\Core\\GPBMetadata\352\002\016Flyteidl::Core'
  _VARIABLEMAP_VARIABLESENTRY._options = None
  _VARIABLEMAP_VARIABLESENTRY._serialized_options = b'8\001'
  _PARAMETERMAP_PARAMETERSENTRY._options = None
  _PARAMETERMAP_PARAMETERSENTRY._serialized_options = b'8\001'
  _globals['_VARIABLE']._serialized_start=139
  _globals['_VARIABLE']._serialized_end=369
  _globals['_VARIABLEMAP']._serialized_start=372
  _globals['_VARIABLEMAP']._serialized_end=545
  _globals['_VARIABLEMAP_VARIABLESENTRY']._serialized_start=460
  _globals['_VARIABLEMAP_VARIABLESENTRY']._serialized_end=545
  _globals['_TYPEDINTERFACE']._serialized_start=547
  _globals['_TYPEDINTERFACE']._serialized_end=669
  _globals['_PARAMETER']._serialized_start=672
  _globals['_PARAMETER']._serialized_end=953
  _globals['_PARAMETERMAP']._serialized_start=956
  _globals['_PARAMETERMAP']._serialized_end=1136
  _globals['_PARAMETERMAP_PARAMETERSENTRY']._serialized_start=1049
  _globals['_PARAMETERMAP_PARAMETERSENTRY']._serialized_end=1136
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from flyteidl.admin import signal_pb2 as flyteidl_dot_admin_dot_signal__pb2


class SignalServiceStub(object):
    """SignalService defines an RPC Service that may create, update, and retrieve signal(s).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetOrCreateSignal = channel.unary_unary(
                '/flyteidl.service.SignalService/GetOrCreateSignal',
                request_serializer=flyteidl_dot_admin_dot_signal__pb2.SignalGetOrCreateRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_signal__pb2.Signal.FromString,
                )
        self.ListSignals = channel.unary_unary(
                '/flyteidl.service.SignalService/ListSignals',
                request_serializer=flyteidl_dot_admin_dot_signal__pb2.SignalListRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_signal__pb2.SignalList.FromString,
                )
        self.SetSignal = channel.unary_unary(
                '/flyteidl.service.SignalService/SetSignal',
                request_serializer=flyteidl_dot_admin_dot_signal__pb2.SignalSetRequest.SerializeToString,
                response_deserializer=flyteidl_dot_admin_dot_signal__pb2.SignalSetResponse.FromString,
                )


class SignalServiceServicer(object):
    """SignalService defines an RPC Service that may create, update, and retrieve signal(s).
    """

    def GetOrCreateSignal(self, request, context):
        """Fetches or creates a :ref:`ref_flyteidl.admin.Signal`.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSignals(self, request, context):
        """Fetch a list of :ref:`ref_flyteidl.admin.Signal` definitions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSignal(self, request, context):
        """Sets the value on a :ref:`ref_flyteidl.admin.Signal` definition
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SignalServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetOrCreateSignal': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrCreateSignal,
                    request_deserializer=flyteidl_dot_admin_dot_signal__pb2.SignalGetOrCreateRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_signal__pb2.Signal.SerializeToString,
            ),
            'ListSignals': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSignals,
                    request_deserializer=flyteidl_dot_admin_dot_signal__pb2.SignalListRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_signal__pb2.SignalList.SerializeToString,
            ),
            'SetSignal': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSignal,
                    request_deserializer=flyteidl_dot_admin_dot_signal__pb2.SignalSetRequest.FromString,
                    response_serializer=flyteidl_dot_admin_dot_signal__pb2.SignalSetResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'flyteidl.service.SignalService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SignalService(object):
    """SignalService defines an RPC Service that may create, update, and retrieve signal(s).
    """

    @staticmethod
    def GetOrCreateSignal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.SignalService/GetOrCreateSignal',
            flyteidl_dot_admin_dot_signal__pb2.SignalGetOrCreateRequest.SerializeToString,
            flyteidl_dot_admin_dot_signal__pb2.Signal.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListSignals(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.SignalService/ListSignals',
            flyteidl_dot_admin_dot_signal__pb2.SignalListRequest.SerializeToString,
            flyteidl_dot_admin_dot_signal__pb2.SignalList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSignal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.service.SignalService/SetSignal',
            flyteidl_dot_admin_dot_signal__pb2.SignalSetRequest.SerializeToString,
            flyteidl_dot_admin_dot_signal__pb2.SignalSetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from flyteidl.core import literals_pb2 as _literals_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateDatasetRequest(_message.Message):
    __slots__ = ["dataset"]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    dataset: Dataset
    def __init__(self, dataset: _Optional[_Union[Dataset, _Mapping]] = ...) -> None: ...

class CreateDatasetResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetDatasetRequest(_message.Message):
    __slots__ = ["dataset"]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    dataset: DatasetID
    def __init__(self, dataset: _Optional[_Union[DatasetID, _Mapping]] = ...) -> None: ...

class GetDatasetResponse(_message.Message):
    __slots__ = ["dataset"]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    dataset: Dataset
    def __init__(self, dataset: _Optional[_Union[Dataset, _Mapping]] = ...) -> None: ...

class GetArtifactRequest(_message.Message):
    __slots__ = ["dataset", "artifact_id", "tag_name"]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    TAG_NAME_FIELD_NUMBER: _ClassVar[int]
    dataset: DatasetID
    artifact_id: str
    tag_name: str
    def __init__(self, dataset: _Optional[_Union[DatasetID, _Mapping]] = ..., artifact_id: _Optional[str] = ..., tag_name: _Optional[str] = ...) -> None: ...

class GetArtifactResponse(_message.Message):
    __slots__ = ["artifact"]
    ARTIFACT_FIELD_NUMBER: _ClassVar[int]
    artifact: Artifact
    def __init__(self, artifact: _Optional[_Union[Artifact, _Mapping]] = ...) -> None: ...

class CreateArtifactRequest(_message.Message):
    __slots__ = ["artifact"]
    ARTIFACT_FIELD_NUMBER: _ClassVar[int]
    artifact: Artifact
    def __init__(self, artifact: _Optional[_Union[Artifact, _Mapping]] = ...) -> None: ...

class CreateArtifactResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class AddTagRequest(_message.Message):
    __slots__ = ["tag"]
    TAG_FIELD_NUMBER: _ClassVar[int]
    tag: Tag
    def __init__(self, tag: _Optional[_Union[Tag, _Mapping]] = ...) -> None: ...

class AddTagResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class ListArtifactsRequest(_message.Message):
    __slots__ = ["dataset", "filter", "pagination"]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    dataset: DatasetID
    filter: FilterExpression
    pagination: PaginationOptions
    def __init__(self, dataset: _Optional[_Union[DatasetID, _Mapping]] = ..., filter: _Optional[_Union[FilterExpression, _Mapping]] = ..., pagination: _Optional[_Union[PaginationOptions, _Mapping]] = ...) -> None: ...

class ListArtifactsResponse(_message.Message):
    __slots__ = ["artifacts", "next_token"]
    ARTIFACTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    artifacts: _containers.RepeatedCompositeFieldContainer[Artifact]
    next_token: str
    def __init__(self, artifacts: _Optional[_Iterable[_Union[Artifact, _Mapping]]] = ..., next_token: _Optional[str] = ...) -> None: ...

class ListDatasetsRequest(_message.Message):
    __slots__ = ["filter", "pagination"]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    filter: FilterExpression
    pagination: PaginationOptions
    def __init__(self, filter: _Optional[_Union[FilterExpression, _Mapping]] = ..., pagination: _Optional[_Union[PaginationOptions, _Mapping]] = ...) -> None: ...

class ListDatasetsResponse(_message.Message):
    __slots__ = ["datasets", "next_token"]
    DATASETS_FIELD_NUMBER: _ClassVar[int]
    NEXT_TOKEN_FIELD_NUMBER: _ClassVar[int]
    datasets: _containers.RepeatedCompositeFieldContainer[Dataset]
    next_token: str
    def __init__(self, datasets: _Optional[_Iterable[_Union[Dataset, _Mapping]]] = ..., next_token: _Optional[str] = ...) -> None: ...

class UpdateArtifactRequest(_message.Message):
    __slots__ = ["dataset", "artifact_id", "tag_name", "data", "metadata"]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    TAG_NAME_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    dataset: DatasetID
    artifact_id: str
    tag_name: str
    data: _containers.RepeatedCompositeFieldContainer[ArtifactData]
    metadata: Metadata
    def __init__(self, dataset: _Optional[_Union[DatasetID, _Mapping]] = ..., artifact_id: _Optional[str] = ..., tag_name: _Optional[str] = ..., data: _Optional[_Iterable[_Union[ArtifactData, _Mapping]]] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class UpdateArtifactResponse(_message.Message):
    __slots__ = ["artifact_id"]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    artifact_id: str
    def __init__(self, artifact_id: _Optional[str] = ...) -> None: ...

class ReservationID(_message.Message):
    __slots__ = ["dataset_id", "tag_name"]
    DATASET_ID_FIELD_NUMBER: _ClassVar[int]
    TAG_NAME_FIELD_NUMBER: _ClassVar[int]
    dataset_id: DatasetID
    tag_name: str
    def __init__(self, dataset_id: _Optional[_Union[DatasetID, _Mapping]] = ..., tag_name: _Optional[str] = ...) -> None: ...

class GetOrExtendReservationRequest(_message.Message):
    __slots__ = ["reservation_id", "owner_id", "heartbeat_interval"]
    RESERVATION_ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    reservation_id: ReservationID
    owner_id: str
    heartbeat_interval: _duration_pb2.Duration
    def __init__(self, reservation_id: _Optional[_Union[ReservationID, _Mapping]] = ..., owner_id: _Optional[str] = ..., heartbeat_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class Reservation(_message.Message):
    __slots__ = ["reservation_id", "owner_id", "heartbeat_interval", "expires_at", "metadata"]
    RESERVATION_ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    HEARTBEAT_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    reservation_id: ReservationID
    owner_id: str
    heartbeat_interval: _duration_pb2.Duration
    expires_at: _timestamp_pb2.Timestamp
    metadata: Metadata
    def __init__(self, reservation_id: _Optional[_Union[ReservationID, _Mapping]] = ..., owner_id: _Optional[str] = ..., heartbeat_interval: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ...) -> None: ...

class GetOrExtendReservationResponse(_message.Message):
    __slots__ = ["reservation"]
    RESERVATION_FIELD_NUMBER: _ClassVar[int]
    reservation: Reservation
    def __init__(self, reservation: _Optional[_Union[Reservation, _Mapping]] = ...) -> None: ...

class ReleaseReservationRequest(_message.Message):
    __slots__ = ["reservation_id", "owner_id"]
    RESERVATION_ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    reservation_id: ReservationID
    owner_id: str
    def __init__(self, reservation_id: _Optional[_Union[ReservationID, _Mapping]] = ..., owner_id: _Optional[str] = ...) -> None: ...

class ReleaseReservationResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class Dataset(_message.Message):
    __slots__ = ["id", "metadata", "partitionKeys"]
    ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PARTITIONKEYS_FIELD_NUMBER: _ClassVar[int]
    id: DatasetID
    metadata: Metadata
    partitionKeys: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[_Union[DatasetID, _Mapping]] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ..., partitionKeys: _Optional[_Iterable[str]] = ...) -> None: ...

class Partition(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class DatasetID(_message.Message):
    __slots__ = ["project", "name", "domain", "version", "UUID", "org"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    UUID_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    project: str
    name: str
    domain: str
    version: str
    UUID: str
    org: str
    def __init__(self, project: _Optional[str] = ..., name: _Optional[str] = ..., domain: _Optional[str] = ..., version: _Optional[str] = ..., UUID: _Optional[str] = ..., org: _Optional[str] = ...) -> None: ...

class Artifact(_message.Message):
    __slots__ = ["id", "dataset", "data", "metadata", "partitions", "tags", "created_at"]
    ID_FIELD_NUMBER: _ClassVar[int]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    dataset: DatasetID
    data: _containers.RepeatedCompositeFieldContainer[ArtifactData]
    metadata: Metadata
    partitions: _containers.RepeatedCompositeFieldContainer[Partition]
    tags: _containers.RepeatedCompositeFieldContainer[Tag]
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., dataset: _Optional[_Union[DatasetID, _Mapping]] = ..., data: _Optional[_Iterable[_Union[ArtifactData, _Mapping]]] = ..., metadata: _Optional[_Union[Metadata, _Mapping]] = ..., partitions: _Optional[_Iterable[_Union[Partition, _Mapping]]] = ..., tags: _Optional[_Iterable[_Union[Tag, _Mapping]]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ArtifactData(_message.Message):
    __slots__ = ["name", "value"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    name: str
    value: _literals_pb2.Literal
    def __init__(self, name: _Optional[str] = ..., value: _Optional[_Union[_literals_pb2.Literal, _Mapping]] = ...) -> None: ...

class Tag(_message.Message):
    __slots__ = ["name", "artifact_id", "dataset"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    DATASET_FIELD_NUMBER: _ClassVar[int]
    name: str
    artifact_id: str
    dataset: DatasetID
    def __init__(self, name: _Optional[str] = ..., artifact_id: _Optional[str] = ..., dataset: _Optional[_Union[DatasetID, _Mapping]] = ...) -> None: ...

class Metadata(_message.Message):
    __slots__ = ["key_map"]
    class KeyMapEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    KEY_MAP_FIELD_NUMBER: _ClassVar[int]
    key_map: _containers.ScalarMap[str, str]
    def __init__(self, key_map: _Optional[_Mapping[str, str]] = ...) -> None: ...

class FilterExpression(_message.Message):
    __slots__ = ["filters"]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    filters: _containers.RepeatedCompositeFieldContainer[SinglePropertyFilter]
    def __init__(self, filters: _Optional[_Iterable[_Union[SinglePropertyFilter, _Mapping]]] = ...) -> None: ...

class SinglePropertyFilter(_message.Message):
    __slots__ = ["tag_filter", "partition_filter", "artifact_filter", "dataset_filter", "operator"]
    class ComparisonOperator(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        EQUALS: _ClassVar[SinglePropertyFilter.ComparisonOperator]
    EQUALS: SinglePropertyFilter.ComparisonOperator
    TAG_FILTER_FIELD_NUMBER: _ClassVar[int]
    PARTITION_FILTER_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_FILTER_FIELD_NUMBER: _ClassVar[int]
    DATASET_FILTER_FIELD_NUMBER: _ClassVar[int]
    OPERATOR_FIELD_NUMBER: _ClassVar[int]
    tag_filter: TagPropertyFilter
    partition_filter: PartitionPropertyFilter
    artifact_filter: ArtifactPropertyFilter
    dataset_filter: DatasetPropertyFilter
    operator: SinglePropertyFilter.ComparisonOperator
    def __init__(self, tag_filter: _Optional[_Union[TagPropertyFilter, _Mapping]] = ..., partition_filter: _Optional[_Union[PartitionPropertyFilter, _Mapping]] = ..., artifact_filter: _Optional[_Union[ArtifactPropertyFilter, _Mapping]] = ..., dataset_filter: _Optional[_Union[DatasetPropertyFilter, _Mapping]] = ..., operator: _Optional[_Union[SinglePropertyFilter.ComparisonOperator, str]] = ...) -> None: ...

class ArtifactPropertyFilter(_message.Message):
    __slots__ = ["artifact_id"]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    artifact_id: str
    def __init__(self, artifact_id: _Optional[str] = ...) -> None: ...

class TagPropertyFilter(_message.Message):
    __slots__ = ["tag_name"]
    TAG_NAME_FIELD_NUMBER: _ClassVar[int]
    tag_name: str
    def __init__(self, tag_name: _Optional[str] = ...) -> None: ...

class PartitionPropertyFilter(_message.Message):
    __slots__ = ["key_val"]
    KEY_VAL_FIELD_NUMBER: _ClassVar[int]
    key_val: KeyValuePair
    def __init__(self, key_val: _Optional[_Union[KeyValuePair, _Mapping]] = ...) -> None: ...

class KeyValuePair(_message.Message):
    __slots__ = ["key", "value"]
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: str
    def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...

class DatasetPropertyFilter(_message.Message):
    __slots__ = ["project", "name", "domain", "version", "org"]
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    project: str
    name: str
    domain: str
    version: str
    org: str
    def __init__(self, project: _Optional[str] = ..., name: _Optional[str] = ..., domain: _Optional[str] = ..., version: _Optional[str] = ..., org: _Optional[str] = ...) -> None: ...

class PaginationOptions(_message.Message):
    __slots__ = ["limit", "token", "sortKey", "sortOrder"]
    class SortOrder(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        DESCENDING: _ClassVar[PaginationOptions.SortOrder]
        ASCENDING: _ClassVar[PaginationOptions.SortOrder]
    DESCENDING: PaginationOptions.SortOrder
    ASCENDING: PaginationOptions.SortOrder
    class SortKey(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        CREATION_TIME: _ClassVar[PaginationOptions.SortKey]
    CREATION_TIME: PaginationOptions.SortKey
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    SORTKEY_FIELD_NUMBER: _ClassVar[int]
    SORTORDER_FIELD_NUMBER: _ClassVar[int]
    limit: int
    token: str
    sortKey: PaginationOptions.SortKey
    sortOrder: PaginationOptions.SortOrder
    def __init__(self, limit: _Optional[int] = ..., token: _Optional[str] = ..., sortKey: _Optional[_Union[PaginationOptions.SortKey, str]] = ..., sortOrder: _Optional[_Union[PaginationOptions.SortOrder, str]] = ...) -> None: ...



from flyteidl.core import tasks_pb2 as _tasks_pb2
from flyteidl.core import workflow_pb2 as _workflow_pb2
from flyteidl.core import literals_pb2 as _literals_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DynamicJobSpec(_message.Message):
    __slots__ = ["nodes", "min_successes", "outputs", "tasks", "subworkflows"]
    NODES_FIELD_NUMBER: _ClassVar[int]
    MIN_SUCCESSES_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    TASKS_FIELD_NUMBER: _ClassVar[int]
    SUBWORKFLOWS_FIELD_NUMBER: _ClassVar[int]
    nodes: _containers.RepeatedCompositeFieldContainer[_workflow_pb2.Node]
    min_successes: int
    outputs: _containers.RepeatedCompositeFieldContainer[_literals_pb2.Binding]
    tasks: _containers.RepeatedCompositeFieldContainer[_tasks_pb2.TaskTemplate]
    subworkflows: _containers.RepeatedCompositeFieldContainer[_workflow_pb2.WorkflowTemplate]
    def __init__(self, nodes: _Optional[_Iterable[_Union[_workflow_pb2.Node, _Mapping]]] = ..., min_successes: _Optional[int] = ..., outputs: _Optional[_Iterable[_Union[_literals_pb2.Binding, _Mapping]]] = ..., tasks: _Optional[_Iterable[_Union[_tasks_pb2.TaskTemplate, _Mapping]]] = ..., subworkflows: _Optional[_Iterable[_Union[_workflow_pb2.WorkflowTemplate, _Mapping]]] = ...) -> None: ...



from flyteidl.core import tasks_pb2 as _tasks_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RestartPolicy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    RESTART_POLICY_NEVER: _ClassVar[RestartPolicy]
    RESTART_POLICY_ON_FAILURE: _ClassVar[RestartPolicy]
    RESTART_POLICY_ALWAYS: _ClassVar[RestartPolicy]
RESTART_POLICY_NEVER: RestartPolicy
RESTART_POLICY_ON_FAILURE: RestartPolicy
RESTART_POLICY_ALWAYS: RestartPolicy

class CommonReplicaSpec(_message.Message):
    __slots__ = ["replicas", "image", "resources", "restart_policy"]
    REPLICAS_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FIELD_NUMBER: _ClassVar[int]
    RESOURCES_FIELD_NUMBER: _ClassVar[int]
    RESTART_POLICY_FIELD_NUMBER: _ClassVar[int]
    replicas: int
    image: str
    resources: _tasks_pb2.Resources
    restart_policy: RestartPolicy
    def __init__(self, replicas: _Optional[int] = ..., image: _Optional[str] = ..., resources: _Optional[_Union[_tasks_pb2.Resources, _Mapping]] = ..., restart_policy: _Optional[_Union[RestartPolicy, str]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x66lyteidl/core/types.proto\x12\rflyteidl.core\x1a\x1cgoogle/protobuf/struct.proto\"\xa1\x02\n\nSchemaType\x12@\n\x07\x63olumns\x18\x03 \x03(\x0b\x32&.flyteidl.core.SchemaType.SchemaColumnR\x07\x63olumns\x1a\xd0\x01\n\x0cSchemaColumn\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12K\n\x04type\x18\x02 \x01(\x0e\x32\x37.flyteidl.core.SchemaType.SchemaColumn.SchemaColumnTypeR\x04type\"_\n\x10SchemaColumnType\x12\x0b\n\x07INTEGER\x10\x00\x12\t\n\x05\x46LOAT\x10\x01\x12\n\n\x06STRING\x10\x02\x12\x0b\n\x07\x42OOLEAN\x10\x03\x12\x0c\n\x08\x44\x41TETIME\x10\x04\x12\x0c\n\x08\x44URATION\x10\x05\"\xc7\x02\n\x15StructuredDatasetType\x12L\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x32.flyteidl.core.StructuredDatasetType.DatasetColumnR\x07\x63olumns\x12\x16\n\x06\x66ormat\x18\x02 \x01(\tR\x06\x66ormat\x12\x30\n\x14\x65xternal_schema_type\x18\x03 \x01(\tR\x12\x65xternalSchemaType\x12\x32\n\x15\x65xternal_schema_bytes\x18\x04 \x01(\x0cR\x13\x65xternalSchemaBytes\x1a\x62\n\rDatasetColumn\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12=\n\x0cliteral_type\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeR\x0bliteralType\"\xa7\x01\n\x08\x42lobType\x12\x16\n\x06\x66ormat\x18\x01 \x01(\tR\x06\x66ormat\x12R\n\x0e\x64imensionality\x18\x02 \x01(\x0e\x32*.flyteidl.core.BlobType.BlobDimensionalityR\x0e\x64imensionality\"/\n\x12\x42lobDimensionality\x12\n\n\x06SINGLE\x10\x00\x12\r\n\tMULTIPART\x10\x01\"\"\n\x08\x45numType\x12\x16\n\x06values\x18\x01 \x03(\tR\x06values\"C\n\tUnionType\x12\x36\n\x08variants\x18\x01 \x03(\x0b\x32\x1a.flyteidl.core.LiteralTypeR\x08variants\"\xd7\x01\n\rTypeStructure\x12\x10\n\x03tag\x18\x01 \x01(\tR\x03tag\x12V\n\x0e\x64\x61taclass_type\x18\x02 \x03(\x0b\x32/.flyteidl.core.TypeStructure.DataclassTypeEntryR\rdataclassType\x1a\\\n\x12\x44\x61taclassTypeEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeR\x05value:\x02\x38\x01\"K\n\x0eTypeAnnotation\x12\x39\n\x0b\x61nnotations\x18\x01 \x01(\x0b\x32\x17.google.protobuf.StructR\x0b\x61nnotations\"\xbc\x05\n\x0bLiteralType\x12\x33\n\x06simple\x18\x01 \x01(\x0e\x32\x19.flyteidl.core.SimpleTypeH\x00R\x06simple\x12\x33\n\x06schema\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.SchemaTypeH\x00R\x06schema\x12\x45\n\x0f\x63ollection_type\x18\x03 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeH\x00R\x0e\x63ollectionType\x12\x42\n\x0emap_value_type\x18\x04 \x01(\x0b\x32\x1a.flyteidl.core.LiteralTypeH\x00R\x0cmapValueType\x12-\n\x04\x62lob\x18\x05 \x01(\x0b\x32\x17.flyteidl.core.BlobTypeH\x00R\x04\x62lob\x12\x36\n\tenum_type\x18\x07 \x01(\x0b\x32\x17.flyteidl.core.EnumTypeH\x00R\x08\x65numType\x12^\n\x17structured_dataset_type\x18\x08 \x01(\x0b\x32$.flyteidl.core.StructuredDatasetTypeH\x00R\x15structuredDatasetType\x12\x39\n\nunion_type\x18\n \x01(\x0b\x32\x18.flyteidl.core.UnionTypeH\x00R\tunionType\x12\x33\n\x08metadata\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructR\x08metadata\x12=\n\nannotation\x18\t \x01(\x0b\x32\x1d.flyteidl.core.TypeAnnotationR\nannotation\x12:\n\tstructure\x18\x0b \x01(\x0b\x32\x1c.flyteidl.core.TypeStructureR\tstructureB\x06\n\x04type\"z\n\x0fOutputReference\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12\x10\n\x03var\x18\x02 \x01(\tR\x03var\x12<\n\tattr_path\x18\x03 \x03(\x0b\x32\x1f.flyteidl.core.PromiseAttributeR\x08\x61ttrPath\"_\n\x10PromiseAttribute\x12#\n\x0cstring_value\x18\x01 \x01(\tH\x00R\x0bstringValue\x12\x1d\n\tint_value\x18\x02 \x01(\x05H\x00R\x08intValueB\x07\n\x05value\"G\n\x05\x45rror\x12$\n\x0e\x66\x61iled_node_id\x18\x01 \x01(\tR\x0c\x66\x61iledNodeId\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message*\x86\x01\n\nSimpleType\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07INTEGER\x10\x01\x12\t\n\x05\x46LOAT\x10\x02\x12\n\n\x06STRING\x10\x03\x12\x0b\n\x07\x42OOLEAN\x10\x04\x12\x0c\n\x08\x44\x41TETIME\x10\x05\x12\x0c\n\x08\x44URATION\x10\x06\x12\n\n\x06\x42INARY\x10\x07\x12\t\n\x05\x45RROR\x10\x08\x12\n\n\x06STRUCT\x10\tB\xb0\x01\n\x11\x63om.flyteidl.coreB\nTypesProtoP\x01Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\xa2\x02\x03\x46\x43X\xaa\x02\rFlyteidl.Core\xca\x02\rFlyteidl\\Core\xe2\x02\x19\x46lyteidl\\Core\\GPBMetadata\xea\x02\x0e\x46lyteidl::Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.core.types_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.flyteidl.coreB\nTypesProtoP\001Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\242\002\003FCX\252\002\rFlyteidl.Core\312\002\rFlyteidl\\Core\342\002\031Flyteidl\\Core\\GPBMetadata\352\002\016Flyteidl::Core'
  _TYPESTRUCTURE_DATACLASSTYPEENTRY._options = None
  _TYPESTRUCTURE_DATACLASSTYPEENTRY._serialized_options = b'8\001'
  _globals['_SIMPLETYPE']._serialized_start=2264
  _globals['_SIMPLETYPE']._serialized_end=2398
  _globals['_SCHEMATYPE']._serialized_start=75
  _globals['_SCHEMATYPE']._serialized_end=364
  _globals['_SCHEMATYPE_SCHEMACOLUMN']._serialized_start=156
  _globals['_SCHEMATYPE_SCHEMACOLUMN']._serialized_end=364
  _globals['_SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE']._serialized_start=269
  _globals['_SCHEMATYPE_SCHEMACOLUMN_SCHEMACOLUMNTYPE']._serialized_end=364
  _globals['_STRUCTUREDDATASETTYPE']._serialized_start=367
  _globals['_STRUCTUREDDATASETTYPE']._serialized_end=694
  _globals['_STRUCTUREDDATASETTYPE_DATASETCOLUMN']._serialized_start=596
  _globals['_STRUCTUREDDATASETTYPE_DATASETCOLUMN']._serialized_end=694
  _globals['_BLOBTYPE']._serialized_start=697
  _globals['_BLOBTYPE']._serialized_end=864
  _globals['_BLOBTYPE_BLOBDIMENSIONALITY']._serialized_start=817
  _globals['_BLOBTYPE_BLOBDIMENSIONALITY']._serialized_end=864
  _globals['_ENUMTYPE']._serialized_start=866
  _globals['_ENUMTYPE']._serialized_end=900
  _globals['_UNIONTYPE']._serialized_start=902
  _globals['_UNIONTYPE']._serialized_end=969
  _globals['_TYPESTRUCTURE']._serialized_start=972
  _globals['_TYPESTRUCTURE']._serialized_end=1187
  _globals['_TYPESTRUCTURE_DATACLASSTYPEENTRY']._serialized_start=1095
  _globals['_TYPESTRUCTURE_DATACLASSTYPEENTRY']._serialized_end=1187
  _globals['_TYPEANNOTATION']._serialized_start=1189
  _globals['_TYPEANNOTATION']._serialized_end=1264
  _globals['_LITERALTYPE']._serialized_start=1267
  _globals['_LITERALTYPE']._serialized_end=1967
  _globals['_OUTPUTREFERENCE']._serialized_start=1969
  _globals['_OUTPUTREFERENCE']._serialized_end=2091
  _globals['_PROMISEATTRIBUTE']._serialized_start=2093
  _globals['_PROMISEATTRIBUTE']._serialized_end=2188
  _globals['_ERROR']._serialized_start=2190
  _globals['_ERROR']._serialized_end=2261
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x66lyteidl/service/auth.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\x17\n\x15OAuth2MetadataRequest\"\xa1\x04\n\x16OAuth2MetadataResponse\x12\x16\n\x06issuer\x18\x01 \x01(\tR\x06issuer\x12\x35\n\x16\x61uthorization_endpoint\x18\x02 \x01(\tR\x15\x61uthorizationEndpoint\x12%\n\x0etoken_endpoint\x18\x03 \x01(\tR\rtokenEndpoint\x12\x38\n\x18response_types_supported\x18\x04 \x03(\tR\x16responseTypesSupported\x12)\n\x10scopes_supported\x18\x05 \x03(\tR\x0fscopesSupported\x12P\n%token_endpoint_auth_methods_supported\x18\x06 \x03(\tR!tokenEndpointAuthMethodsSupported\x12\x19\n\x08jwks_uri\x18\x07 \x01(\tR\x07jwksUri\x12G\n code_challenge_methods_supported\x18\x08 \x03(\tR\x1d\x63odeChallengeMethodsSupported\x12\x32\n\x15grant_types_supported\x18\t \x03(\tR\x13grantTypesSupported\x12\x42\n\x1d\x64\x65vice_authorization_endpoint\x18\n \x01(\tR\x1b\x64\x65viceAuthorizationEndpoint\"\x1f\n\x1dPublicClientAuthConfigRequest\"\x86\x02\n\x1ePublicClientAuthConfigResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12!\n\x0credirect_uri\x18\x02 \x01(\tR\x0bredirectUri\x12\x16\n\x06scopes\x18\x03 \x03(\tR\x06scopes\x12<\n\x1a\x61uthorization_metadata_key\x18\x04 \x01(\tR\x18\x61uthorizationMetadataKey\x12\x32\n\x15service_http_endpoint\x18\x05 \x01(\tR\x13serviceHttpEndpoint\x12\x1a\n\x08\x61udience\x18\x06 \x01(\tR\x08\x61udience2\xfc\x03\n\x13\x41uthMetadataService\x12\xf5\x01\n\x11GetOAuth2Metadata\x12\'.flyteidl.service.OAuth2MetadataRequest\x1a(.flyteidl.service.OAuth2MetadataResponse\"\x8c\x01\x92\x41Z\x1aXRetrieves OAuth2 authorization server metadata. This endpoint is anonymously accessible.\x82\xd3\xe4\x93\x02)\x12\'/.well-known/oauth-authorization-server\x12\xec\x01\n\x15GetPublicClientConfig\x12/.flyteidl.service.PublicClientAuthConfigRequest\x1a\x30.flyteidl.service.PublicClientAuthConfigResponse\"p\x92\x41N\x1aLRetrieves public flyte client info. This endpoint is anonymously accessible.\x82\xd3\xe4\x93\x02\x19\x12\x17/config/v1/flyte_clientB\xc1\x01\n\x14\x63om.flyteidl.serviceB\tAuthProtoP\x01Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/service\xa2\x02\x03\x46SX\xaa\x02\x10\x46lyteidl.Service\xca\x02\x10\x46lyteidl\\Service\xe2\x02\x1c\x46lyteidl\\Service\\GPBMetadata\xea\x02\x11\x46lyteidl::Serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.service.auth_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.flyteidl.serviceB\tAuthProtoP\001Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/service\242\002\003FSX\252\002\020Flyteidl.Service\312\002\020Flyteidl\\Service\342\002\034Flyteidl\\Service\\GPBMetadata\352\002\021Flyteidl::Service'
  _AUTHMETADATASERVICE.methods_by_name['GetOAuth2Metadata']._options = None
  _AUTHMETADATASERVICE.methods_by_name['GetOAuth2Metadata']._serialized_options = b'\222AZ\032XRetrieves OAuth2 authorization server metadata. This endpoint is anonymously accessible.\202\323\344\223\002)\022\'/.well-known/oauth-authorization-server'
  _AUTHMETADATASERVICE.methods_by_name['GetPublicClientConfig']._options = None
  _AUTHMETADATASERVICE.methods_by_name['GetPublicClientConfig']._serialized_options = b'\222AN\032LRetrieves public flyte client info. This endpoint is anonymously accessible.\202\323\344\223\002\031\022\027/config/v1/flyte_client'
  _globals['_OAUTH2METADATAREQUEST']._serialized_start=127
  _globals['_OAUTH2METADATAREQUEST']._serialized_end=150
  _globals['_OAUTH2METADATARESPONSE']._serialized_start=153
  _globals['_OAUTH2METADATARESPONSE']._serialized_end=698
  _globals['_PUBLICCLIENTAUTHCONFIGREQUEST']._serialized_start=700
  _globals['_PUBLICCLIENTAUTHCONFIGREQUEST']._serialized_end=731
  _globals['_PUBLICCLIENTAUTHCONFIGRESPONSE']._serialized_start=734
  _globals['_PUBLICCLIENTAUTHCONFIGRESPONSE']._serialized_end=996
  _globals['_AUTHMETADATASERVICE']._serialized_start=999
  _globals['_AUTHMETADATASERVICE']._serialized_end=1507
# @@protoc_insertion_point(module_scope)



from flyteidl.core import types_pb2 as _types_pb2
from flyteidl.core import literals_pb2 as _literals_pb2
from flyteidl.core import artifact_id_pb2 as _artifact_id_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Variable(_message.Message):
    __slots__ = ["type", "description", "artifact_partial_id", "artifact_tag"]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_PARTIAL_ID_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_TAG_FIELD_NUMBER: _ClassVar[int]
    type: _types_pb2.LiteralType
    description: str
    artifact_partial_id: _artifact_id_pb2.ArtifactID
    artifact_tag: _artifact_id_pb2.ArtifactTag
    def __init__(self, type: _Optional[_Union[_types_pb2.LiteralType, _Mapping]] = ..., description: _Optional[str] = ..., artifact_partial_id: _Optional[_Union[_artifact_id_pb2.ArtifactID, _Mapping]] = ..., artifact_tag: _Optional[_Union[_artifact_id_pb2.ArtifactTag, _Mapping]] = ...) -> None: ...

class VariableMap(_message.Message):
    __slots__ = ["variables"]
    class VariablesEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Variable
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Variable, _Mapping]] = ...) -> None: ...
    VARIABLES_FIELD_NUMBER: _ClassVar[int]
    variables: _containers.MessageMap[str, Variable]
    def __init__(self, variables: _Optional[_Mapping[str, Variable]] = ...) -> None: ...

class TypedInterface(_message.Message):
    __slots__ = ["inputs", "outputs"]
    INPUTS_FIELD_NUMBER: _ClassVar[int]
    OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    inputs: VariableMap
    outputs: VariableMap
    def __init__(self, inputs: _Optional[_Union[VariableMap, _Mapping]] = ..., outputs: _Optional[_Union[VariableMap, _Mapping]] = ...) -> None: ...

class Parameter(_message.Message):
    __slots__ = ["var", "default", "required", "artifact_query", "artifact_id"]
    VAR_FIELD_NUMBER: _ClassVar[int]
    DEFAULT_FIELD_NUMBER: _ClassVar[int]
    REQUIRED_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_QUERY_FIELD_NUMBER: _ClassVar[int]
    ARTIFACT_ID_FIELD_NUMBER: _ClassVar[int]
    var: Variable
    default: _literals_pb2.Literal
    required: bool
    artifact_query: _artifact_id_pb2.ArtifactQuery
    artifact_id: _artifact_id_pb2.ArtifactID
    def __init__(self, var: _Optional[_Union[Variable, _Mapping]] = ..., default: _Optional[_Union[_literals_pb2.Literal, _Mapping]] = ..., required: bool = ..., artifact_query: _Optional[_Union[_artifact_id_pb2.ArtifactQuery, _Mapping]] = ..., artifact_id: _Optional[_Union[_artifact_id_pb2.ArtifactID, _Mapping]] = ...) -> None: ...

class ParameterMap(_message.Message):
    __slots__ = ["parameters"]
    class ParametersEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Parameter
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Parameter, _Mapping]] = ...) -> None: ...
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    parameters: _containers.MessageMap[str, Parameter]
    def __init__(self, parameters: _Optional[_Mapping[str, Parameter]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/dynamic_job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2
from flyteidl.core import workflow_pb2 as flyteidl_dot_core_dot_workflow__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x66lyteidl/core/dynamic_job.proto\x12\rflyteidl.core\x1a\x19\x66lyteidl/core/tasks.proto\x1a\x1c\x66lyteidl/core/workflow.proto\x1a\x1c\x66lyteidl/core/literals.proto\"\x8a\x02\n\x0e\x44ynamicJobSpec\x12)\n\x05nodes\x18\x01 \x03(\x0b\x32\x13.flyteidl.core.NodeR\x05nodes\x12#\n\rmin_successes\x18\x02 \x01(\x03R\x0cminSuccesses\x12\x30\n\x07outputs\x18\x03 \x03(\x0b\x32\x16.flyteidl.core.BindingR\x07outputs\x12\x31\n\x05tasks\x18\x04 \x03(\x0b\x32\x1b.flyteidl.core.TaskTemplateR\x05tasks\x12\x43\n\x0csubworkflows\x18\x05 \x03(\x0b\x32\x1f.flyteidl.core.WorkflowTemplateR\x0csubworkflowsB\xb5\x01\n\x11\x63om.flyteidl.coreB\x0f\x44ynamicJobProtoP\x01Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\xa2\x02\x03\x46\x43X\xaa\x02\rFlyteidl.Core\xca\x02\rFlyteidl\\Core\xe2\x02\x19\x46lyteidl\\Core\\GPBMetadata\xea\x02\x0e\x46lyteidl::Coreb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.core.dynamic_job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021com.flyteidl.coreB\017DynamicJobProtoP\001Z:github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/core\242\002\003FCX\252\002\rFlyteidl.Core\312\002\rFlyteidl\\Core\342\002\031Flyteidl\\Core\\GPBMetadata\352\002\016Flyteidl::Core'
  _globals['_DYNAMICJOBSPEC']._serialized_start=138
  _globals['_DYNAMICJOBSPEC']._serialized_end=404
# @@protoc_insertion_point(module_scope)



from flyteidl.core import identifier_pb2 as _identifier_pb2
from flyteidl.admin import common_pb2 as _common_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DescriptionFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    DESCRIPTION_FORMAT_UNKNOWN: _ClassVar[DescriptionFormat]
    DESCRIPTION_FORMAT_MARKDOWN: _ClassVar[DescriptionFormat]
    DESCRIPTION_FORMAT_HTML: _ClassVar[DescriptionFormat]
    DESCRIPTION_FORMAT_RST: _ClassVar[DescriptionFormat]
DESCRIPTION_FORMAT_UNKNOWN: DescriptionFormat
DESCRIPTION_FORMAT_MARKDOWN: DescriptionFormat
DESCRIPTION_FORMAT_HTML: DescriptionFormat
DESCRIPTION_FORMAT_RST: DescriptionFormat

class DescriptionEntity(_message.Message):
    __slots__ = ["id", "short_description", "long_description", "source_code", "tags"]
    ID_FIELD_NUMBER: _ClassVar[int]
    SHORT_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LONG_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    SOURCE_CODE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    id: _identifier_pb2.Identifier
    short_description: str
    long_description: Description
    source_code: SourceCode
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[_Union[_identifier_pb2.Identifier, _Mapping]] = ..., short_description: _Optional[str] = ..., long_description: _Optional[_Union[Description, _Mapping]] = ..., source_code: _Optional[_Union[SourceCode, _Mapping]] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class Description(_message.Message):
    __slots__ = ["value", "uri", "format", "icon_link"]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    URI_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    ICON_LINK_FIELD_NUMBER: _ClassVar[int]
    value: str
    uri: str
    format: DescriptionFormat
    icon_link: str
    def __init__(self, value: _Optional[str] = ..., uri: _Optional[str] = ..., format: _Optional[_Union[DescriptionFormat, str]] = ..., icon_link: _Optional[str] = ...) -> None: ...

class SourceCode(_message.Message):
    __slots__ = ["link"]
    LINK_FIELD_NUMBER: _ClassVar[int]
    link: str
    def __init__(self, link: _Optional[str] = ...) -> None: ...

class DescriptionEntityList(_message.Message):
    __slots__ = ["descriptionEntities", "token"]
    DESCRIPTIONENTITIES_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    descriptionEntities: _containers.RepeatedCompositeFieldContainer[DescriptionEntity]
    token: str
    def __init__(self, descriptionEntities: _Optional[_Iterable[_Union[DescriptionEntity, _Mapping]]] = ..., token: _Optional[str] = ...) -> None: ...

class DescriptionEntityListRequest(_message.Message):
    __slots__ = ["resource_type", "id", "limit", "token", "filters", "sort_by"]
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    resource_type: _identifier_pb2.ResourceType
    id: _common_pb2.NamedEntityIdentifier
    limit: int
    token: str
    filters: str
    sort_by: _common_pb2.Sort
    def __init__(self, resource_type: _Optional[_Union[_identifier_pb2.ResourceType, str]] = ..., id: _Optional[_Union[_common_pb2.NamedEntityIdentifier, _Mapping]] = ..., limit: _Optional[int] = ..., token: _Optional[str] = ..., filters: _Optional[str] = ..., sort_by: _Optional[_Union[_common_pb2.Sort, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/service/signal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from flyteidl.admin import signal_pb2 as flyteidl_dot_admin_dot_signal__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x66lyteidl/service/signal.proto\x12\x10\x66lyteidl.service\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x66lyteidl/admin/signal.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xe7\x05\n\rSignalService\x12\x90\x01\n\x11GetOrCreateSignal\x12(.flyteidl.admin.SignalGetOrCreateRequest\x1a\x16.flyteidl.admin.Signal\"9\x92\x41\x36\x1a\x34Retrieve a signal, creating it if it does not exist.\x12\x8e\x02\n\x0bListSignals\x12!.flyteidl.admin.SignalListRequest\x1a\x1a.flyteidl.admin.SignalList\"\xbf\x01\x92\x41I\x1aGFetch existing signal definitions matching the input signal id filters.\x82\xd3\xe4\x93\x02m\x12k/api/v1/signals/{workflow_execution_id.project}/{workflow_execution_id.domain}/{workflow_execution_id.name}\x12\xb1\x02\n\tSetSignal\x12 .flyteidl.admin.SignalSetRequest\x1a!.flyteidl.admin.SignalSetResponse\"\xde\x01\x92\x41\xc0\x01\x1a\x13Set a signal value.JB\n\x03\x34\x30\x30\x12;\n9Returned for bad request that may have failed validation.Je\n\x03\x34\x30\x39\x12^\n\\Returned for a request that references an identical entity that has already been registered.\x82\xd3\xe4\x93\x02\x14:\x01*\"\x0f/api/v1/signalsB\xc3\x01\n\x14\x63om.flyteidl.serviceB\x0bSignalProtoP\x01Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/service\xa2\x02\x03\x46SX\xaa\x02\x10\x46lyteidl.Service\xca\x02\x10\x46lyteidl\\Service\xe2\x02\x1c\x46lyteidl\\Service\\GPBMetadata\xea\x02\x11\x46lyteidl::Serviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.service.signal_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.flyteidl.serviceB\013SignalProtoP\001Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/service\242\002\003FSX\252\002\020Flyteidl.Service\312\002\020Flyteidl\\Service\342\002\034Flyteidl\\Service\\GPBMetadata\352\002\021Flyteidl::Service'
  _SIGNALSERVICE.methods_by_name['GetOrCreateSignal']._options = None
  _SIGNALSERVICE.methods_by_name['GetOrCreateSignal']._serialized_options = b'\222A6\0324Retrieve a signal, creating it if it does not exist.'
  _SIGNALSERVICE.methods_by_name['ListSignals']._options = None
  _SIGNALSERVICE.methods_by_name['ListSignals']._serialized_options = b'\222AI\032GFetch existing signal definitions matching the input signal id filters.\202\323\344\223\002m\022k/api/v1/signals/{workflow_execution_id.project}/{workflow_execution_id.domain}/{workflow_execution_id.name}'
  _SIGNALSERVICE.methods_by_name['SetSignal']._options = None
  _SIGNALSERVICE.methods_by_name['SetSignal']._serialized_options = b'\222A\300\001\032\023Set a signal value.JB\n\003400\022;\n9Returned for bad request that may have failed validation.Je\n\003409\022^\n\\Returned for a request that references an identical entity that has already been registered.\202\323\344\223\002\024:\001*\"\017/api/v1/signals'
  _globals['_SIGNALSERVICE']._serialized_start=159
  _globals['_SIGNALSERVICE']._serialized_end=902
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/spark.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x66lyteidl/plugins/spark.proto\x12\x10\x66lyteidl.plugins\x1a\x1cgoogle/protobuf/struct.proto\x1a\x19\x66lyteidl/core/tasks.proto\"B\n\x10SparkApplication\".\n\x04Type\x12\n\n\x06PYTHON\x10\x00\x12\x08\n\x04JAVA\x10\x01\x12\t\n\x05SCALA\x10\x02\x12\x05\n\x01R\x10\x03\"\xec\x05\n\x08SparkJob\x12Q\n\x0f\x61pplicationType\x18\x01 \x01(\x0e\x32\'.flyteidl.plugins.SparkApplication.TypeR\x0f\x61pplicationType\x12\x30\n\x13mainApplicationFile\x18\x02 \x01(\tR\x13mainApplicationFile\x12\x1c\n\tmainClass\x18\x03 \x01(\tR\tmainClass\x12G\n\tsparkConf\x18\x04 \x03(\x0b\x32).flyteidl.plugins.SparkJob.SparkConfEntryR\tsparkConf\x12J\n\nhadoopConf\x18\x05 \x03(\x0b\x32*.flyteidl.plugins.SparkJob.HadoopConfEntryR\nhadoopConf\x12\"\n\x0c\x65xecutorPath\x18\x06 \x01(\tR\x0c\x65xecutorPath\x12?\n\x0e\x64\x61tabricksConf\x18\x07 \x01(\x0b\x32\x17.google.protobuf.StructR\x0e\x64\x61tabricksConf\x12(\n\x0f\x64\x61tabricksToken\x18\x08 \x01(\tR\x0f\x64\x61tabricksToken\x12.\n\x12\x64\x61tabricksInstance\x18\t \x01(\tR\x12\x64\x61tabricksInstance\x12\x33\n\tdriverPod\x18\n \x01(\x0b\x32\x15.flyteidl.core.K8sPodR\tdriverPod\x12\x37\n\x0b\x65xecutorPod\x18\x0b \x01(\x0b\x32\x15.flyteidl.core.K8sPodR\x0b\x65xecutorPod\x1a<\n\x0eSparkConfEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a=\n\x0fHadoopConfEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xc2\x01\n\x14\x63om.flyteidl.pluginsB\nSparkProtoP\x01Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/plugins\xa2\x02\x03\x46PX\xaa\x02\x10\x46lyteidl.Plugins\xca\x02\x10\x46lyteidl\\Plugins\xe2\x02\x1c\x46lyteidl\\Plugins\\GPBMetadata\xea\x02\x11\x46lyteidl::Pluginsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'flyteidl.plugins.spark_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.flyteidl.pluginsB\nSparkProtoP\001Z=github.com/flyteorg/flyte/flyteidl/gen/pb-go/flyteidl/plugins\242\002\003FPX\252\002\020Flyteidl.Plugins\312\002\020Flyteidl\\Plugins\342\002\034Flyteidl\\Plugins\\GPBMetadata\352\002\021Flyteidl::Plugins'
  _SPARKJOB_SPARKCONFENTRY._options = None
  _SPARKJOB_SPARKCONFENTRY._serialized_options = b'8\001'
  _SPARKJOB_HADOOPCONFENTRY._options = None
  _SPARKJOB_HADOOPCONFENTRY._serialized_options = b'8\001'
  _globals['_SPARKAPPLICATION']._serialized_start=107
  _globals['_SPARKAPPLICATION']._serialized_end=173
  _globals['_SPARKAPPLICATION_TYPE']._serialized_start=127
  _globals['_SPARKAPPLICATION_TYPE']._serialized_end=173
  _globals['_SPARKJOB']._serialized_start=176
  _globals['_SPARKJOB']._serialized_end=924
  _globals['_SPARKJOB_SPARKCONFENTRY']._serialized_start=801
  _globals['_SPARKJOB_SPARKCONFENTRY']._serialized_end=861
  _globals['_SPARKJOB_HADOOPCONFENTRY']._serialized_start=863
  _globals['_SPARKJOB_HADOOPCONFENTRY']._serialized_end=924
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from flyteidl.cacheservice import cacheservice_pb2 as flyteidl_dot_cacheservice_dot_cacheservice__pb2


class CacheServiceStub(object):
    """
    CacheService defines operations for cache management including retrieval, storage, and deletion of cached task/workflow outputs.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/flyteidl.cacheservice.CacheService/Get',
                request_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetCacheRequest.SerializeToString,
                response_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetCacheResponse.FromString,
                )
        self.Put = channel.unary_unary(
                '/flyteidl.cacheservice.CacheService/Put',
                request_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.PutCacheRequest.SerializeToString,
                response_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.PutCacheResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/flyteidl.cacheservice.CacheService/Delete',
                request_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.DeleteCacheRequest.SerializeToString,
                response_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.DeleteCacheResponse.FromString,
                )
        self.GetOrExtendReservation = channel.unary_unary(
                '/flyteidl.cacheservice.CacheService/GetOrExtendReservation',
                request_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetOrExtendReservationRequest.SerializeToString,
                response_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetOrExtendReservationResponse.FromString,
                )
        self.ReleaseReservation = channel.unary_unary(
                '/flyteidl.cacheservice.CacheService/ReleaseReservation',
                request_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.ReleaseReservationRequest.SerializeToString,
                response_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.ReleaseReservationResponse.FromString,
                )


class CacheServiceServicer(object):
    """
    CacheService defines operations for cache management including retrieval, storage, and deletion of cached task/workflow outputs.
    """

    def Get(self, request, context):
        """Retrieves cached data by key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Put(self, request, context):
        """Stores or updates cached data by key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes cached data by key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrExtendReservation(self, request, context):
        """Get or extend a reservation for a cache key
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReleaseReservation(self, request, context):
        """Release the reservation for a cache key
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CacheServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetCacheRequest.FromString,
                    response_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetCacheResponse.SerializeToString,
            ),
            'Put': grpc.unary_unary_rpc_method_handler(
                    servicer.Put,
                    request_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.PutCacheRequest.FromString,
                    response_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.PutCacheResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.DeleteCacheRequest.FromString,
                    response_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.DeleteCacheResponse.SerializeToString,
            ),
            'GetOrExtendReservation': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrExtendReservation,
                    request_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetOrExtendReservationRequest.FromString,
                    response_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetOrExtendReservationResponse.SerializeToString,
            ),
            'ReleaseReservation': grpc.unary_unary_rpc_method_handler(
                    servicer.ReleaseReservation,
                    request_deserializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.ReleaseReservationRequest.FromString,
                    response_serializer=flyteidl_dot_cacheservice_dot_cacheservice__pb2.ReleaseReservationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'flyteidl.cacheservice.CacheService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CacheService(object):
    """
    CacheService defines operations for cache management including retrieval, storage, and deletion of cached task/workflow outputs.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.cacheservice.CacheService/Get',
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetCacheRequest.SerializeToString,
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetCacheResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Put(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.cacheservice.CacheService/Put',
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.PutCacheRequest.SerializeToString,
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.PutCacheResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.cacheservice.CacheService/Delete',
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.DeleteCacheRequest.SerializeToString,
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.DeleteCacheResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrExtendReservation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.cacheservice.CacheService/GetOrExtendReservation',
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetOrExtendReservationRequest.SerializeToString,
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.GetOrExtendReservationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReleaseReservation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/flyteidl.cacheservice.CacheService/ReleaseReservation',
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.ReleaseReservationRequest.SerializeToString,
            flyteidl_dot_cacheservice_dot_cacheservice__pb2.ReleaseReservationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Secret(_message.Message):
    __slots__ = ["group", "group_version", "key", "mount_requirement", "env_var"]
    class MountType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        ANY: _ClassVar[Secret.MountType]
        ENV_VAR: _ClassVar[Secret.MountType]
        FILE: _ClassVar[Secret.MountType]
    ANY: Secret.MountType
    ENV_VAR: Secret.MountType
    FILE: Secret.MountType
    GROUP_FIELD_NUMBER: _ClassVar[int]
    GROUP_VERSION_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    MOUNT_REQUIREMENT_FIELD_NUMBER: _ClassVar[int]
    ENV_VAR_FIELD_NUMBER: _ClassVar[int]
    group: str
    group_version: str
    key: str
    mount_requirement: Secret.MountType
    env_var: str
    def __init__(self, group: _Optional[str] = ..., group_version: _Optional[str] = ..., key: _Optional[str] = ..., mount_requirement: _Optional[_Union[Secret.MountType, str]] = ..., env_var: _Optional[str] = ...) -> None: ...

class OAuth2Client(_message.Message):
    __slots__ = ["client_id", "client_secret"]
    CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_SECRET_FIELD_NUMBER: _ClassVar[int]
    client_id: str
    client_secret: Secret
    def __init__(self, client_id: _Optional[str] = ..., client_secret: _Optional[_Union[Secret, _Mapping]] = ...) -> None: ...

class Identity(_message.Message):
    __slots__ = ["iam_role", "k8s_service_account", "oauth2_client", "execution_identity"]
    IAM_ROLE_FIELD_NUMBER: _ClassVar[int]
    K8S_SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    OAUTH2_CLIENT_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_IDENTITY_FIELD_NUMBER: _ClassVar[int]
    iam_role: str
    k8s_service_account: str
    oauth2_client: OAuth2Client
    execution_identity: str
    def __init__(self, iam_role: _Optional[str] = ..., k8s_service_account: _Optional[str] = ..., oauth2_client: _Optional[_Union[OAuth2Client, _Mapping]] = ..., execution_identity: _Optional[str] = ...) -> None: ...

class OAuth2TokenRequest(_message.Message):
    __slots__ = ["name", "type", "client", "idp_discovery_endpoint", "token_endpoint"]
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        CLIENT_CREDENTIALS: _ClassVar[OAuth2TokenRequest.Type]
    CLIENT_CREDENTIALS: OAuth2TokenRequest.Type
    NAME_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CLIENT_FIELD_NUMBER: _ClassVar[int]
    IDP_DISCOVERY_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    TOKEN_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    name: str
    type: OAuth2TokenRequest.Type
    client: OAuth2Client
    idp_discovery_endpoint: str
    token_endpoint: str
    def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[OAuth2TokenRequest.Type, str]] = ..., client: _Optional[_Union[OAuth2Client, _Mapping]] = ..., idp_discovery_endpoint: _Optional[str] = ..., token_endpoint: _Optional[str] = ...) -> None: ...

class SecurityContext(_message.Message):
    __slots__ = ["run_as", "secrets", "tokens"]
    RUN_AS_FIELD_NUMBER: _ClassVar[int]
    SECRETS_FIELD_NUMBER: _ClassVar[int]
    TOKENS_FIELD_NUMBER: _ClassVar[int]
    run_as: Identity
    secrets: _containers.RepeatedCompositeFieldContainer[Secret]
    tokens: _containers.RepeatedCompositeFieldContainer[OAuth2TokenRequest]
    def __init__(self, run_as: _Optional[_Union[Identity, _Mapping]] = ..., secrets: _Optional[_Iterable[_Union[Secret, _Mapping]]] = ..., tokens: _Optional[_Iterable[_Union[OAuth2TokenRequest, _Mapping]]] = ...) -> None: ...



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SimpleType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    NONE: _ClassVar[SimpleType]
    INTEGER: _ClassVar[SimpleType]
    FLOAT: _ClassVar[SimpleType]
    STRING: _ClassVar[SimpleType]
    BOOLEAN: _ClassVar[SimpleType]
    DATETIME: _ClassVar[SimpleType]
    DURATION: _ClassVar[SimpleType]
    BINARY: _ClassVar[SimpleType]
    ERROR: _ClassVar[SimpleType]
    STRUCT: _ClassVar[SimpleType]
NONE: SimpleType
INTEGER: SimpleType
FLOAT: SimpleType
STRING: SimpleType
BOOLEAN: SimpleType
DATETIME: SimpleType
DURATION: SimpleType
BINARY: SimpleType
ERROR: SimpleType
STRUCT: SimpleType

class SchemaType(_message.Message):
    __slots__ = ["columns"]
    class SchemaColumn(_message.Message):
        __slots__ = ["name", "type"]
        class SchemaColumnType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
            INTEGER: _ClassVar[SchemaType.SchemaColumn.SchemaColumnType]
            FLOAT: _ClassVar[SchemaType.SchemaColumn.SchemaColumnType]
            STRING: _ClassVar[SchemaType.SchemaColumn.SchemaColumnType]
            BOOLEAN: _ClassVar[SchemaType.SchemaColumn.SchemaColumnType]
            DATETIME: _ClassVar[SchemaType.SchemaColumn.SchemaColumnType]
            DURATION: _ClassVar[SchemaType.SchemaColumn.SchemaColumnType]
        INTEGER: SchemaType.SchemaColumn.SchemaColumnType
        FLOAT: SchemaType.SchemaColumn.SchemaColumnType
        STRING: SchemaType.SchemaColumn.SchemaColumnType
        BOOLEAN: SchemaType.SchemaColumn.SchemaColumnType
        DATETIME: SchemaType.SchemaColumn.SchemaColumnType
        DURATION: SchemaType.SchemaColumn.SchemaColumnType
        NAME_FIELD_NUMBER: _ClassVar[int]
        TYPE_FIELD_NUMBER: _ClassVar[int]
        name: str
        type: SchemaType.SchemaColumn.SchemaColumnType
        def __init__(self, name: _Optional[str] = ..., type: _Optional[_Union[SchemaType.SchemaColumn.SchemaColumnType, str]] = ...) -> None: ...
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    columns: _containers.RepeatedCompositeFieldContainer[SchemaType.SchemaColumn]
    def __init__(self, columns: _Optional[_Iterable[_Union[SchemaType.SchemaColumn, _Mapping]]] = ...) -> None: ...

class StructuredDatasetType(_message.Message):
    __slots__ = ["columns", "format", "external_schema_type", "external_schema_bytes"]
    class DatasetColumn(_message.Message):
        __slots__ = ["name", "literal_type"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        LITERAL_TYPE_FIELD_NUMBER: _ClassVar[int]
        name: str
        literal_type: LiteralType
        def __init__(self, name: _Optional[str] = ..., literal_type: _Optional[_Union[LiteralType, _Mapping]] = ...) -> None: ...
    COLUMNS_FIELD_NUMBER: _ClassVar[int]
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_SCHEMA_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXTERNAL_SCHEMA_BYTES_FIELD_NUMBER: _ClassVar[int]
    columns: _containers.RepeatedCompositeFieldContainer[StructuredDatasetType.DatasetColumn]
    format: str
    external_schema_type: str
    external_schema_bytes: bytes
    def __init__(self, columns: _Optional[_Iterable[_Union[StructuredDatasetType.DatasetColumn, _Mapping]]] = ..., format: _Optional[str] = ..., external_schema_type: _Optional[str] = ..., external_schema_bytes: _Optional[bytes] = ...) -> None: ...

class BlobType(_message.Message):
    __slots__ = ["format", "dimensionality"]
    class BlobDimensionality(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        SINGLE: _ClassVar[BlobType.BlobDimensionality]
        MULTIPART: _ClassVar[BlobType.BlobDimensionality]
    SINGLE: BlobType.BlobDimensionality
    MULTIPART: BlobType.BlobDimensionality
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    DIMENSIONALITY_FIELD_NUMBER: _ClassVar[int]
    format: str
    dimensionality: BlobType.BlobDimensionality
    def __init__(self, format: _Optional[str] = ..., dimensionality: _Optional[_Union[BlobType.BlobDimensionality, str]] = ...) -> None: ...

class EnumType(_message.Message):
    __slots__ = ["values"]
    VALUES_FIELD_NUMBER: _ClassVar[int]
    values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, values: _Optional[_Iterable[str]] = ...) -> None: ...

class UnionType(_message.Message):
    __slots__ = ["variants"]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    variants: _containers.RepeatedCompositeFieldContainer[LiteralType]
    def __init__(self, variants: _Optional[_Iterable[_Union[LiteralType, _Mapping]]] = ...) -> None: ...

class TypeStructure(_message.Message):
    __slots__ = ["tag", "dataclass_type"]
    class DataclassTypeEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: LiteralType
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[LiteralType, _Mapping]] = ...) -> None: ...
    TAG_FIELD_NUMBER: _ClassVar[int]
    DATACLASS_TYPE_FIELD_NUMBER: _ClassVar[int]
    tag: str
    dataclass_type: _containers.MessageMap[str, LiteralType]
    def __init__(self, tag: _Optional[str] = ..., dataclass_type: _Optional[_Mapping[str, LiteralType]] = ...) -> None: ...

class TypeAnnotation(_message.Message):
    __slots__ = ["annotations"]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    annotations: _struct_pb2.Struct
    def __init__(self, annotations: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class LiteralType(_message.Message):
    __slots__ = ["simple", "schema", "collection_type", "map_value_type", "blob", "enum_type", "structured_dataset_type", "union_type", "metadata", "annotation", "structure"]
    SIMPLE_FIELD_NUMBER: _ClassVar[int]
    SCHEMA_FIELD_NUMBER: _ClassVar[int]
    COLLECTION_TYPE_FIELD_NUMBER: _ClassVar[int]
    MAP_VALUE_TYPE_FIELD_NUMBER: _ClassVar[int]
    BLOB_FIELD_NUMBER: _ClassVar[int]
    ENUM_TYPE_FIELD_NUMBER: _ClassVar[int]
    STRUCTURED_DATASET_TYPE_FIELD_NUMBER: _ClassVar[int]
    UNION_TYPE_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    ANNOTATION_FIELD_NUMBER: _ClassVar[int]
    STRUCTURE_FIELD_NUMBER: _ClassVar[int]
    simple: SimpleType
    schema: SchemaType
    collection_type: LiteralType
    map_value_type: LiteralType
    blob: BlobType
    enum_type: EnumType
    structured_dataset_type: StructuredDatasetType
    union_type: UnionType
    metadata: _struct_pb2.Struct
    annotation: TypeAnnotation
    structure: TypeStructure
    def __init__(self, simple: _Optional[_Union[SimpleType, str]] = ..., schema: _Optional[_Union[SchemaType, _Mapping]] = ..., collection_type: _Optional[_Union[LiteralType, _Mapping]] = ..., map_value_type: _Optional[_Union[LiteralType, _Mapping]] = ..., blob: _Optional[_Union[BlobType, _Mapping]] = ..., enum_type: _Optional[_Union[EnumType, _Mapping]] = ..., structured_dataset_type: _Optional[_Union[StructuredDatasetType, _Mapping]] = ..., union_type: _Optional[_Union[UnionType, _Mapping]] = ..., metadata: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., annotation: _Optional[_Union[TypeAnnotation, _Mapping]] = ..., structure: _Optional[_Union[TypeStructure, _Mapping]] = ...) -> None: ...

class OutputReference(_message.Message):
    __slots__ = ["node_id", "var", "attr_path"]
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    VAR_FIELD_NUMBER: _ClassVar[int]
    ATTR_PATH_FIELD_NUMBER: _ClassVar[int]
    node_id: str
    var: str
    attr_path: _containers.RepeatedCompositeFieldContainer[PromiseAttribute]
    def __init__(self, node_id: _Optional[str] = ..., var: _Optional[str] = ..., attr_path: _Optional[_Iterable[_Union[PromiseAttribute, _Mapping]]] = ...) -> None: ...

class PromiseAttribute(_message.Message):
    __slots__ = ["string_value", "int_value"]
    STRING_VALUE_FIELD_NUMBER: _ClassVar[int]
    INT_VALUE_FIELD_NUMBER: _ClassVar[int]
    string_value: str
    int_value: int
    def __init__(self, string_value: _Optional[str] = ..., int_value: _Optional[int] = ...) -> None: ...

class Error(_message.Message):
    __slots__ = ["failed_node_id", "message"]
    FAILED_NODE_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    failed_node_id: str
    message: str
    def __init__(self, failed_node_id: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...
